@@ -13,9 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-# @author: Carl Baldwin, Hewlett-Packard
 
 import pbr.version
 
-target = 'rackspace-python-neutronclient'
-__version__ = pbr.version.VersionInfo(target).version_string()
+
+version_info = pbr.version.VersionInfo('rackspace-python-neutronclient')
+__version__ = version_info.version_string()
